package SBOM::CycloneDX::Vulnerability::Reference;

use 5.010001;
use strict;
use warnings;
use utf8;

use Types::Standard qw(Str InstanceOf);

use Moo;
use namespace::autoclean;

extends 'SBOM::CycloneDX::Base';

has id => (is => 'rw', isa => Str, required => 1);
has source => (is => 'rw', isa => InstanceOf ['SBOM::CycloneDX::Vulnerability::Source'], required => 1);

sub TO_JSON {

    my $self = shift;

    my $json = {id => $self->id, source => $self->source};

    return $json;

}

1;

=encoding utf-8

=head1 NAME

SBOM::CycloneDX::Vulnerability::Reference - Vulnerability reference

=head1 SYNOPSIS

    SBOM::CycloneDX::Vulnerability::Reference->new();


=head1 DESCRIPTION

L<SBOM::CycloneDX::Vulnerability::Reference> provide the vulnerability reference object.

=head2 METHODS

L<SBOM::CycloneDX::Vulnerability::Reference> inherits all methods from L<SBOM::CycloneDX::Base>
and implements the following new ones.

=over

=item SBOM::CycloneDX::Vulnerability::Reference->new( %PARAMS )

Properties:

=over

=item C<id>, An identifier that uniquely identifies the vulnerability.

=item C<source>, The source that published the vulnerability.

=back

=item $reference->id

=item $reference->source

=back


=head1 SUPPORT

=head2 Bugs / Feature Requests

Please report any bugs or feature requests through the issue tracker
at L<https://github.com/giterlizzi/perl-SBOM-CycloneDX/issues>.
You will be notified automatically of any progress on your issue.

=head2 Source Code

This is open source software.  The code repository is available for
public review and contribution under the terms of the license.

L<https://github.com/giterlizzi/perl-SBOM-CycloneDX>

    git clone https://github.com/giterlizzi/perl-SBOM-CycloneDX.git


=head1 AUTHOR

=over 4

=item * Giuseppe Di Terlizzi <gdt@cpan.org>

=back


=head1 LICENSE AND COPYRIGHT

This software is copyright (c) 2025 by Giuseppe Di Terlizzi.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
